@@ -1,23 +1,6 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     zyc <zyc@uniontech.com>
-*
-* Maintainer:  zyc <zyc@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "logauththread.h"
 #include "utils.h"
@@ -316,7 +299,18 @@ void LogAuthThread::handleKern()
             return;
         }
 
-        auto token = DLDBusHandler::instance(this)->openLogStream(m_FilePath.at(i));
+        //如果是压缩文件，对其解压缩
+        QString filePath = m_FilePath.at(i);
+        if(QString::compare(QFileInfo(filePath).suffix(), "gz", Qt::CaseInsensitive) == 0){
+            QStringList filePathList = DLDBusHandler::instance(this)->getFileInfo(filePath);
+            if(filePathList.size()){
+                filePath = filePathList.at(0);
+            }else {
+                filePath = "";
+            }
+        }
+
+        auto token = DLDBusHandler::instance(this)->openLogStream(filePath);
         QString byte;
         while(1) {
             auto temp = DLDBusHandler::instance(this)->readLogInStream(token);
