@@ -1,23 +1,6 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:    LZ <zhou.lu@archermind.com>
-*
-* Maintainer:  LZ <zhou.lu@archermind.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "logcollectormain.h"
 #include "logsettings.h"
@@ -26,8 +9,6 @@
 #include "logallexportthread.h"
 #include "exportprogressdlg.h"
 
-#include <qsettingbackend.h>
-
 #include <DApplication>
 #include <DTitlebar>
 #include <DWindowOptionButton>
@@ -82,6 +63,11 @@ LogCollectorMain::~LogCollectorMain()
         delete m_searchEdt;
         m_searchEdt = nullptr;
     }
+
+    if (m_backend) {
+        delete m_backend;
+        m_backend = nullptr;
+    }
     //如果窗体状态不是最大最小状态，则记录此时窗口尺寸到配置文件里，方便下次打开时恢复大小
     if (windowState() == Qt::WindowNoState) {
         LogSettings::instance()->saveConfigWinSize(width(), height());
@@ -285,8 +271,8 @@ void LogCollectorMain::initSettings()
     if (!dir.exists()) {
         Utils::mkMutiDir(configpath);
     };
-    auto backend = new QSettingBackend(dir.filePath("config.conf"), m_settings);
-    m_settings->setBackend(backend);
+    m_backend = new QSettingBackend(dir.filePath("config.conf"), m_settings);
+    m_settings->setBackend(m_backend);
 }
 
 void LogCollectorMain::exportAllLogs()
